@@ -13,6 +13,15 @@ from django.core import exceptions
 from django.utils.translation import ugettext_lazy as _
 from django.db.models import fields
 from django.utils.encoding import smart_unicode
+try:
+	## in south >= 0.6, we have to explicitly tell south about this
+	## custom field.  Even though it will be on an unmanaged model, 
+	## south parses everything first and will crap out even though
+	## later it'd ignore this model anyway.
+	from south.modelsinspector import add_introspection_rules
+	add_introspection_rules([], ["^salesforce\.fields\.SalesforceAutoField"])
+except ImportError:
+	pass
 
 class SalesforceAutoField(fields.Field):
 	"""
